===========================
Application Catalog service
===========================

.. toctree::
   :maxdepth: 2

   get_started.rst
   install.rst
   verify.rst
   next-steps.rst

The Murano Project introduces an application catalog to OpenStack, enabling
application developers and cloud administrators to publish various cloud-ready
applications in a browsable categorized catalog. Cloud users -- including
inexperienced ones -- can then use the catalog to compose reliable application
environments with the push of a button.

This chapter assumes a working setup of OpenStack following the
`OpenStack Installation Tutorial
<https://docs.openstack.org/latest/install/>`_.
